@@ -14,17 +14,17 @@ use_rcpp <- function() {
   if (uses_roxygen()) {
     todo("Include the following roxygen tags somewhere in your package")
     code_block(
-      paste0("#' @useDynLib ", project_name(), ", .registration = TRUE"),
+      "#' @useDynLib {project_name()}, .registration = TRUE",
       "#' @importFrom Rcpp sourceCpp",
       "NULL"
     )
   } else {
     todo("Include the following directives in your NAMESPACE")
     code_block(
-      paste0("useDynLib('", project_name(), "', .registration = TRUE)"),
+      "useDynLib('{project_name()}', .registration = TRUE)",
       "importFrom('Rcpp', 'sourceCpp')"
     )
     edit_file(proj_path("NAMESPACE"))
   }
-  todo("Run document()")
+  todo("Run {code('devtools::document()')}")
 }
