@@ -19,16 +19,16 @@
 #' use_rmarkdown_template()
 #' }
 use_rmarkdown_template <- function(template_name = "Template Name",
-                                   template_dir = slug(template_name, ""),
+                                   template_dir = asciify(template_name),
                                    template_description = "A description of the template",
                                    template_create_dir = FALSE) {
 
   # Process some of the inputs
   template_create_dir <- as.character(template_create_dir)
-  template_dir <- file.path("inst", "rmarkdown", "templates", template_dir)
+  template_dir <- path("inst", "rmarkdown", "templates", template_dir)
 
   # Scaffold files
-  use_directory(file.path(template_dir, "skeleton"))
+  use_directory(path(template_dir, "skeleton"))
   use_template(
     "rmarkdown-template.yml",
     data = list(
@@ -37,12 +37,12 @@ use_rmarkdown_template <- function(template_name = "Template Name",
       template_description = template_description,
       template_create_dir = template_create_dir
     ),
-    save_as = file.path(template_dir, "template.yml")
+    save_as = path(template_dir, "template.yaml")
   )
 
   use_template(
     "rmarkdown-template.Rmd",
-    file.path(template_dir, "skeleton", "skeleton.Rmd")
+    path(template_dir, "skeleton", "skeleton.Rmd")
   )
 
   invisible(TRUE)
